"""
Python module generated from Java source file org.bukkit.event.player.AsyncPlayerPreLoginEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.net import InetAddress
from java.util import UUID
from org.bukkit.event import Event
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class AsyncPlayerPreLoginEvent(Event):
    """
    Stores details for players attempting to log in.
    
    This event is asynchronous, and not run using main thread.
    """

    def __init__(self, name: str, ipAddress: "InetAddress"):
        ...


    def __init__(self, name: str, ipAddress: "InetAddress", uniqueId: "UUID"):
        ...


    def __init__(self, name: str, ipAddress: "InetAddress", uniqueId: "UUID", transferred: bool):
        ...


    def getLoginResult(self) -> "Result":
        """
        Gets the current result of the login, as an enum

        Returns
        - Current Result of the login
        """
        ...


    def getResult(self) -> "PlayerPreLoginEvent.Result":
        """
        Gets the current result of the login, as an enum

        Returns
        - Current Result of the login

        See
        - .getLoginResult()

        Deprecated
        - This method uses a deprecated enum from PlayerPreLoginEvent
        """
        ...


    def setLoginResult(self, result: "Result") -> None:
        """
        Sets the new result of the login, as an enum

        Arguments
        - result: New result to set
        """
        ...


    def setResult(self, result: "PlayerPreLoginEvent.Result") -> None:
        """
        Sets the new result of the login, as an enum

        Arguments
        - result: New result to set

        See
        - .setLoginResult(Result)

        Deprecated
        - This method uses a deprecated enum from PlayerPreLoginEvent
        """
        ...


    def getKickMessage(self) -> str:
        """
        Gets the current kick message that will be used if getResult() !=
        Result.ALLOWED

        Returns
        - Current kick message
        """
        ...


    def setKickMessage(self, message: str) -> None:
        """
        Sets the kick message to display if getResult() != Result.ALLOWED

        Arguments
        - message: New kick message
        """
        ...


    def allow(self) -> None:
        """
        Allows the player to log in
        """
        ...


    def disallow(self, result: "Result", message: str) -> None:
        """
        Disallows the player from logging in, with the given reason

        Arguments
        - result: New result for disallowing the player
        - message: Kick message to display to the user
        """
        ...


    def disallow(self, result: "PlayerPreLoginEvent.Result", message: str) -> None:
        """
        Disallows the player from logging in, with the given reason

        Arguments
        - result: New result for disallowing the player
        - message: Kick message to display to the user

        See
        - .disallow(Result, String)

        Deprecated
        - This method uses a deprecated enum from PlayerPreLoginEvent
        """
        ...


    def getName(self) -> str:
        """
        Gets the player's name.

        Returns
        - the player's name
        """
        ...


    def getAddress(self) -> "InetAddress":
        """
        Gets the player IP address.

        Returns
        - The IP address
        """
        ...


    def getUniqueId(self) -> "UUID":
        """
        Gets the player's unique ID.

        Returns
        - The unique ID
        """
        ...


    def isTransferred(self) -> bool:
        """
        Gets if this connection has been transferred from another server.

        Returns
        - True if the connection has been transferred
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class Result(Enum):
        """
        Basic kick reasons for communicating to plugins
        """

        ALLOWED = 0
        """
        The player is allowed to log in
        """
        KICK_FULL = 1
        """
        The player is not allowed to log in, due to the server being full
        """
        KICK_BANNED = 2
        """
        The player is not allowed to log in, due to them being banned
        """
        KICK_WHITELIST = 3
        """
        The player is not allowed to log in, due to them not being on the
        white list
        """
        KICK_OTHER = 4
        """
        The player is not allowed to log in, for reasons undefined
        """



"""
Python module generated from Java source file com.google.common.util.concurrent.Striped

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import MoreObjects
from com.google.common.base import Preconditions
from com.google.common.base import Supplier
from com.google.common.collect import ImmutableList
from com.google.common.collect import MapMaker
from com.google.common.math import IntMath
from com.google.common.primitives import Ints
from com.google.common.util.concurrent import *
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from java.math import RoundingMode
from java.util import Arrays
from java.util import Collections
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import Semaphore
from java.util.concurrent.atomic import AtomicReferenceArray
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import Lock
from java.util.concurrent.locks import ReadWriteLock
from java.util.concurrent.locks import ReentrantLock
from java.util.concurrent.locks import ReentrantReadWriteLock
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Striped:
    """
    A striped `Lock/Semaphore/ReadWriteLock`. This offers the underlying lock striping similar
    to that of `ConcurrentHashMap` in a reusable form, and extends it for semaphores and
    read-write locks. Conceptually, lock striping is the technique of dividing a lock into many
    *stripes*, increasing the granularity of a single lock and allowing independent operations
    to lock different stripes and proceed concurrently, instead of creating contention for a single
    lock.
    
    The guarantee provided by this class is that equal keys lead to the same lock (or semaphore),
    i.e. `if (key1.equals(key2))` then `striped.get(key1) == striped.get(key2)` (assuming
    Object.hashCode() is correctly implemented for the keys). Note that if `key1` is
    <strong>not</strong> equal to `key2`, it is <strong>not</strong> guaranteed that `striped.get(key1) != striped.get(key2)`; the elements might nevertheless be mapped to the same
    lock. The lower the number of stripes, the higher the probability of this happening.
    
    There are three flavors of this class: `Striped<Lock>`, `Striped<Semaphore>`, and
    `Striped<ReadWriteLock>`. For each type, two implementations are offered: .lock(int) strong and .lazyWeakLock(int) weak `Striped<Lock>`, .semaphore(int, int) strong and .lazyWeakSemaphore(int, int) weak `Striped<Semaphore>`, and .readWriteLock(int) strong and .lazyWeakReadWriteLock(int) weak `Striped<ReadWriteLock>`. *Strong* means that all
    stripes (locks/semaphores) are initialized eagerly, and are not reclaimed unless `Striped`
    itself is reclaimable. *Weak* means that locks/semaphores are created lazily, and they are
    allowed to be reclaimed if nobody is holding on to them. This is useful, for example, if one
    wants to create a `Striped<Lock>` of many locks, but worries that in most cases only a
    small portion of these would be in use.
    
    Prior to this class, one might be tempted to use `Map<K, Lock>`, where `K`
    represents the task. This maximizes concurrency by having each unique key mapped to a unique
    lock, but also maximizes memory footprint. On the other extreme, one could use a single lock for
    all tasks, which minimizes memory footprint but also minimizes concurrency. Instead of choosing
    either of these extremes, `Striped` allows the user to trade between required concurrency
    and memory footprint. For example, if a set of tasks are CPU-bound, one could easily create a
    very compact `Striped<Lock>` of `availableProcessors() * 4` stripes, instead of
    possibly thousands of locks which could be created in a `Map<K, Lock>` structure.

    Author(s)
    - Dimitris Andreou

    Since
    - 13.0
    """

    def get(self, key: "Object") -> "L":
        """
        Returns the stripe that corresponds to the passed key. It is always guaranteed that if `key1.equals(key2)`, then `get(key1) == get(key2)`.

        Arguments
        - key: an arbitrary, non-null key

        Returns
        - the stripe that the passed key corresponds to
        """
        ...


    def getAt(self, index: int) -> "L":
        """
        Returns the stripe at the specified index. Valid indexes are 0, inclusively, to `size()`,
        exclusively.

        Arguments
        - index: the index of the stripe to return; must be in `[0...size())`

        Returns
        - the stripe at the specified index
        """
        ...


    def size(self) -> int:
        """
        Returns the total number of stripes in this instance.
        """
        ...


    def bulkGet(self, keys: Iterable["Object"]) -> Iterable["L"]:
        """
        Returns the stripes that correspond to the passed objects, in ascending (as per .getAt(int)) order. Thus, threads that use the stripes in the order returned by this method
        are guaranteed to not deadlock each other.
        
        It should be noted that using a `Striped<L>` with relatively few stripes, and `bulkGet(keys)` with a relative large number of keys can cause an excessive number of shared
        stripes (much like the birthday paradox, where much fewer than anticipated birthdays are needed
        for a pair of them to match). Please consider carefully the implications of the number of
        stripes, the intended concurrency level, and the typical number of keys used in a `bulkGet(keys)` operation. See <a href="http://www.mathpages.com/home/kmath199.htm">Balls in
        Bins model</a> for mathematical formulas that can be used to estimate the probability of
        collisions.

        Arguments
        - keys: arbitrary non-null keys

        Returns
        - the stripes corresponding to the objects (one per each object, derived by delegating to
            .get(Object); may contain duplicates), in an increasing index order.
        """
        ...


    @staticmethod
    def lock(stripes: int) -> "Striped"["Lock"]:
        """
        Creates a `Striped<Lock>` with eagerly initialized, strongly referenced locks. Every lock
        is reentrant.

        Arguments
        - stripes: the minimum number of stripes (locks) required

        Returns
        - a new `Striped<Lock>`
        """
        ...


    @staticmethod
    def lazyWeakLock(stripes: int) -> "Striped"["Lock"]:
        """
        Creates a `Striped<Lock>` with lazily initialized, weakly referenced locks. Every lock is
        reentrant.

        Arguments
        - stripes: the minimum number of stripes (locks) required

        Returns
        - a new `Striped<Lock>`
        """
        ...


    @staticmethod
    def semaphore(stripes: int, permits: int) -> "Striped"["Semaphore"]:
        """
        Creates a `Striped<Semaphore>` with eagerly initialized, strongly referenced semaphores,
        with the specified number of permits.

        Arguments
        - stripes: the minimum number of stripes (semaphores) required
        - permits: the number of permits in each semaphore

        Returns
        - a new `Striped<Semaphore>`
        """
        ...


    @staticmethod
    def lazyWeakSemaphore(stripes: int, permits: int) -> "Striped"["Semaphore"]:
        """
        Creates a `Striped<Semaphore>` with lazily initialized, weakly referenced semaphores,
        with the specified number of permits.

        Arguments
        - stripes: the minimum number of stripes (semaphores) required
        - permits: the number of permits in each semaphore

        Returns
        - a new `Striped<Semaphore>`
        """
        ...


    @staticmethod
    def readWriteLock(stripes: int) -> "Striped"["ReadWriteLock"]:
        """
        Creates a `Striped<ReadWriteLock>` with eagerly initialized, strongly referenced
        read-write locks. Every lock is reentrant.

        Arguments
        - stripes: the minimum number of stripes (locks) required

        Returns
        - a new `Striped<ReadWriteLock>`
        """
        ...


    @staticmethod
    def lazyWeakReadWriteLock(stripes: int) -> "Striped"["ReadWriteLock"]:
        """
        Creates a `Striped<ReadWriteLock>` with lazily initialized, weakly referenced read-write
        locks. Every lock is reentrant.

        Arguments
        - stripes: the minimum number of stripes (locks) required

        Returns
        - a new `Striped<ReadWriteLock>`
        """
        ...



"""
Python module generated from Java source file java.security.CodeSigner

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.security import *
from java.security.cert import CertPath
from typing import Any, Callable, Iterable, Tuple


class CodeSigner(Serializable):

    def __init__(self, signerCertPath: "CertPath", timestamp: "Timestamp"):
        """
        Constructs a CodeSigner object.

        Arguments
        - signerCertPath: The signer's certificate path.
                              It must not be `null`.
        - timestamp: A signature timestamp.
                         If `null` then no timestamp was generated
                         for the signature.

        Raises
        - NullPointerException: if `signerCertPath` is
                                     `null`.
        """
        ...


    def getSignerCertPath(self) -> "CertPath":
        """
        Returns the signer's certificate path.

        Returns
        - A certificate path.
        """
        ...


    def getTimestamp(self) -> "Timestamp":
        """
        Returns the signature timestamp.

        Returns
        - The timestamp or `null` if none is present.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this code signer.
        The hash code is generated using the signer's certificate path and the
        timestamp, if present.

        Returns
        - a hash code value for this code signer.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Tests for equality between the specified object and this
        code signer. Two code signers are considered equal if their
        signer certificate paths are equal and if their timestamps are equal,
        if present in both.

        Arguments
        - obj: the object to test for equality with this object.

        Returns
        - True if the objects are considered equal, False otherwise.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string describing this code signer.

        Returns
        - A string comprising the signer's certificate and a timestamp,
                if present.
        """
        ...



"""
Python module generated from Java source file com.google.common.annotations.GwtIncompatible

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import *
from typing import Any, Callable, Iterable, Tuple


class GwtIncompatible:
    """
    The presence of this annotation on an API indicates that the method may *not* be used with
    the <a href="http://www.gwtproject.org/">Google Web Toolkit</a> (GWT).
    
    This annotation behaves identically to <a href=
    "http://www.gwtproject.org/javadoc/latest/com/google/gwt/core/shared/GwtIncompatible.html">the
    `@GwtIncompatible` annotation in GWT itself</a>.

    Author(s)
    - Charles Fry
    """

    def value(self) -> str:
        """
        Describes why the annotated element is incompatible with GWT. Since this is generally due to a
        dependence on a type/method which GWT doesn't support, it is sufficient to simply reference the
        unsupported type/method. E.g. "Class.isInstance".
        
        As of Guava 20.0, this value is optional. We encourage authors who wish to describe why an
        API is `@GwtIncompatible` to instead leave an implementation comment.
        """
        return ""



"""
Python module generated from Java source file java.util.concurrent.FutureTask

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util.concurrent import *
from java.util.concurrent.locks import LockSupport
from typing import Any, Callable, Iterable, Tuple


class FutureTask(RunnableFuture):
    """
    A cancellable asynchronous computation.  This class provides a base
    implementation of Future, with methods to start and cancel
    a computation, query to see if the computation is complete, and
    retrieve the result of the computation.  The result can only be
    retrieved when the computation has completed; the `get`
    methods will block if the computation has not yet completed.  Once
    the computation has completed, the computation cannot be restarted
    or cancelled (unless the computation is invoked using
    .runAndReset).
    
    A `FutureTask` can be used to wrap a Callable or
    Runnable object.  Because `FutureTask` implements
    `Runnable`, a `FutureTask` can be submitted to an
    Executor for execution.
    
    In addition to serving as a standalone class, this class provides
    `protected` functionality that may be useful when creating
    customized task classes.
    
    Type `<V>`: The result type returned by this FutureTask's `get` methods

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self, callable: "Callable"["V"]):
        """
        Creates a `FutureTask` that will, upon running, execute the
        given `Callable`.

        Arguments
        - callable: the callable task

        Raises
        - NullPointerException: if the callable is null
        """
        ...


    def __init__(self, runnable: "Runnable", result: "V"):
        """
        Creates a `FutureTask` that will, upon running, execute the
        given `Runnable`, and arrange that `get` will return the
        given result on successful completion.

        Arguments
        - runnable: the runnable task
        - result: the result to return on successful completion. If
        you don't need a particular result, consider using
        constructions of the form:
        `Future<?> f = new FutureTask<Void>(runnable, null)`

        Raises
        - NullPointerException: if the runnable is null
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def isDone(self) -> bool:
        ...


    def cancel(self, mayInterruptIfRunning: bool) -> bool:
        ...


    def get(self) -> "V":
        """
        Raises
        - CancellationException: 
        """
        ...


    def get(self, timeout: int, unit: "TimeUnit") -> "V":
        """
        Raises
        - CancellationException: 
        """
        ...


    def run(self) -> None:
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this FutureTask.

        Returns
        - a string representation of this FutureTask

        Unknown Tags
        - The default implementation returns a string identifying this
        FutureTask, as well as its completion state.  The state, in
        brackets, contains one of the strings `"Completed Normally"`,
        `"Completed Exceptionally"`, `"Cancelled"`, or `"Not completed"`.
        """
        ...



"""
Python module generated from Java source file com.google.common.math.PairedStatsAccumulator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.math import *
from com.google.common.primitives import Doubles
from typing import Any, Callable, Iterable, Tuple


class PairedStatsAccumulator:
    """
    A mutable object which accumulates paired double values (e.g. points on a plane) and tracks some
    basic statistics over all the values added so far. This class is not thread safe.

    Author(s)
    - Pete Gillin

    Since
    - 20.0
    """

    def add(self, x: float, y: float) -> None:
        """
        Adds the given pair of values to the dataset.
        """
        ...


    def addAll(self, values: "PairedStats") -> None:
        """
        Adds the given statistics to the dataset, as if the individual values used to compute the
        statistics had been added directly.
        """
        ...


    def snapshot(self) -> "PairedStats":
        """
        Returns an immutable snapshot of the current statistics.
        """
        ...


    def count(self) -> int:
        """
        Returns the number of pairs in the dataset.
        """
        ...


    def xStats(self) -> "Stats":
        """
        Returns an immutable snapshot of the statistics on the `x` values alone.
        """
        ...


    def yStats(self) -> "Stats":
        """
        Returns an immutable snapshot of the statistics on the `y` values alone.
        """
        ...


    def populationCovariance(self) -> float:
        """
        Returns the population covariance of the values. The count must be non-zero.
        
        This is guaranteed to return zero if the dataset contains a single pair of finite values. It
        is not guaranteed to return zero when the dataset consists of the same pair of values multiple
        times, due to numerical errors.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...


    def sampleCovariance(self) -> float:
        """
        Returns the sample covariance of the values. The count must be greater than one.
        
        This is not guaranteed to return zero when the dataset consists of the same pair of values
        multiple times, due to numerical errors.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty or contains a single pair of values
        """
        ...


    def pearsonsCorrelationCoefficient(self) -> float:
        """
        Returns the <a href="http://mathworld.wolfram.com/CorrelationCoefficient.html">Pearson's or
        product-moment correlation coefficient</a> of the values. The count must greater than one, and
        the `x` and `y` values must both have non-zero population variance (i.e. `xStats().populationVariance() > 0.0 && yStats().populationVariance() > 0.0`). The result is not
        guaranteed to be exactly +/-1 even when the data are perfectly (anti-)correlated, due to
        numerical errors. However, it is guaranteed to be in the inclusive range [-1, +1].
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty or contains a single pair of values, or
            either the `x` and `y` dataset has zero population variance
        """
        ...


    def leastSquaresFit(self) -> "LinearTransformation":
        """
        Returns a linear transformation giving the best fit to the data according to <a
        href="http://mathworld.wolfram.com/LeastSquaresFitting.html">Ordinary Least Squares linear
        regression</a> of `y` as a function of `x`. The count must be greater than one, and
        either the `x` or `y` data must have a non-zero population variance (i.e. `xStats().populationVariance() > 0.0 || yStats().populationVariance() > 0.0`). The result is
        guaranteed to be horizontal if there is variance in the `x` data but not the `y`
        data, and vertical if there is variance in the `y` data but not the `x` data.
        
        This fit minimizes the root-mean-square error in `y` as a function of `x`. This
        error is defined as the square root of the mean of the squares of the differences between the
        actual `y` values of the data and the values predicted by the fit for the `x`
        values (i.e. it is the square root of the mean of the squares of the vertical distances between
        the data points and the best fit line). For this fit, this error is a fraction `sqrt(1 -
        R*R)` of the population standard deviation of `y`, where `R` is the Pearson's
        correlation coefficient (as given by .pearsonsCorrelationCoefficient()).
        
        The corresponding root-mean-square error in `x` as a function of `y` is a
        fraction `sqrt(1/(R*R) - 1)` of the population standard deviation of `x`. This fit
        does not normally minimize that error: to do that, you should swap the roles of `x` and
        `y`.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is LinearTransformation.forNaN().

        Raises
        - IllegalStateException: if the dataset is empty or contains a single pair of values, or
            both the `x` and `y` dataset have zero population variance
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.nodes.SequenceNode

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.nodes import *
from typing import Any, Callable, Iterable, Tuple


class SequenceNode(CollectionNode):
    """
    Represents a sequence.
    
    A sequence is a ordered collection of nodes.
    """

    def __init__(self, tag: "Tag", resolved: bool, value: list["Node"], startMark: "Mark", endMark: "Mark", flowStyle: "DumperOptions.FlowStyle"):
        ...


    def __init__(self, tag: "Tag", value: list["Node"], flowStyle: "DumperOptions.FlowStyle"):
        ...


    def getNodeId(self) -> "NodeId":
        ...


    def getValue(self) -> list["Node"]:
        """
        Returns the elements in this sequence.

        Returns
        - Nodes in the specified order.
        """
        ...


    def setListType(self, listType: type["Object"]) -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file java.util.concurrent.ConcurrentSkipListMap

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Serializable
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util import AbstractCollection
from java.util import AbstractSet
from java.util import Collections
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from java.util import NoSuchElementException
from java.util import SortedMap
from java.util import Spliterator
from java.util.concurrent import *
from java.util.concurrent.atomic import LongAdder
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import Consumer
from java.util.function import Function
from java.util.function import Predicate
from typing import Any, Callable, Iterable, Tuple


class ConcurrentSkipListMap(AbstractMap, ConcurrentNavigableMap, Cloneable, Serializable):
    """
    A scalable concurrent ConcurrentNavigableMap implementation.
    The map is sorted according to the Comparable natural
    ordering of its keys, or by a Comparator provided at map
    creation time, depending on which constructor is used.
    
    This class implements a concurrent variant of <a
    href="http://en.wikipedia.org/wiki/Skip_list" target="_top">SkipLists</a>
    providing expected average *log(n)* time cost for the
    `containsKey`, `get`, `put` and
    `remove` operations and their variants.  Insertion, removal,
    update, and access operations safely execute concurrently by
    multiple threads.
    
    Iterators and spliterators are
    <a href="package-summary.html#Weakly">*weakly consistent*</a>.
    
    Ascending key ordered views and their iterators are faster than
    descending ones.
    
    All `Map.Entry` pairs returned by methods in this class
    and its views represent snapshots of mappings at the time they were
    produced. They do *not* support the `Entry.setValue`
    method. (Note however that it is possible to change mappings in the
    associated map using `put`, `putIfAbsent`, or
    `replace`, depending on exactly which effect you need.)
    
    Beware that bulk operations `putAll`, `equals`,
    `toArray`, `containsValue`, and `clear` are
    *not* guaranteed to be performed atomically. For example, an
    iterator operating concurrently with a `putAll` operation
    might view only some of the added elements.
    
    This class and its views and iterators implement all of the
    *optional* methods of the Map and Iterator
    interfaces. Like most other concurrent collections, this class does
    *not* permit the use of `null` keys or values because some
    null return values cannot be reliably distinguished from the absence of
    elements.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<K>`: the type of keys maintained by this map
    
    Type `<V>`: the type of mapped values

    Author(s)
    - Doug Lea

    Since
    - 1.6
    """

    def __init__(self):
        """
        Constructs a new, empty map, sorted according to the
        Comparable natural ordering of the keys.
        """
        ...


    def __init__(self, comparator: "Comparator"["K"]):
        """
        Constructs a new, empty map, sorted according to the specified
        comparator.

        Arguments
        - comparator: the comparator that will be used to order this map.
               If `null`, the Comparable natural
               ordering of the keys will be used.
        """
        ...


    def __init__(self, m: dict["K", "V"]):
        """
        Constructs a new map containing the same mappings as the given map,
        sorted according to the Comparable natural ordering of
        the keys.

        Arguments
        - m: the map whose mappings are to be placed in this map

        Raises
        - ClassCastException: if the keys in `m` are not
                Comparable, or are not mutually comparable
        - NullPointerException: if the specified map or any of its keys
                or values are null
        """
        ...


    def __init__(self, m: "SortedMap"["K", "V"]):
        """
        Constructs a new map containing the same mappings and using the
        same ordering as the specified sorted map.

        Arguments
        - m: the sorted map whose mappings are to be placed in this
               map, and whose comparator is to be used to sort this map

        Raises
        - NullPointerException: if the specified sorted map or any of
                its keys or values are null
        """
        ...


    def clone(self) -> "ConcurrentSkipListMap"["K", "V"]:
        """
        Returns a shallow copy of this `ConcurrentSkipListMap`
        instance. (The keys and values themselves are not cloned.)

        Returns
        - a shallow copy of this map
        """
        ...


    def containsKey(self, key: "Object") -> bool:
        """
        Returns `True` if this map contains a mapping for the specified
        key.

        Arguments
        - key: key whose presence in this map is to be tested

        Returns
        - `True` if this map contains a mapping for the specified key

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key is null
        """
        ...


    def get(self, key: "Object") -> "V":
        """
        Returns the value to which the specified key is mapped,
        or `null` if this map contains no mapping for the key.
        
        More formally, if this map contains a mapping from a key
        `k` to a value `v` such that `key` compares
        equal to `k` according to the map's ordering, then this
        method returns `v`; otherwise it returns `null`.
        (There can be at most one such mapping.)

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key is null
        """
        ...


    def getOrDefault(self, key: "Object", defaultValue: "V") -> "V":
        """
        Returns the value to which the specified key is mapped,
        or the given defaultValue if this map contains no mapping for the key.

        Arguments
        - key: the key
        - defaultValue: the value to return if this map contains
        no mapping for the given key

        Returns
        - the mapping for the key, if present; else the defaultValue

        Raises
        - NullPointerException: if the specified key is null

        Since
        - 1.8
        """
        ...


    def put(self, key: "K", value: "V") -> "V":
        """
        Associates the specified value with the specified key in this map.
        If the map previously contained a mapping for the key, the old
        value is replaced.

        Arguments
        - key: key with which the specified value is to be associated
        - value: value to be associated with the specified key

        Returns
        - the previous value associated with the specified key, or
                `null` if there was no mapping for the key

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key or value is null
        """
        ...


    def remove(self, key: "Object") -> "V":
        """
        Removes the mapping for the specified key from this map if present.

        Arguments
        - key: key for which mapping should be removed

        Returns
        - the previous value associated with the specified key, or
                `null` if there was no mapping for the key

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key is null
        """
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Returns `True` if this map maps one or more keys to the
        specified value.  This operation requires time linear in the
        map size. Additionally, it is possible for the map to change
        during execution of this method, in which case the returned
        result may be inaccurate.

        Arguments
        - value: value whose presence in this map is to be tested

        Returns
        - `True` if a mapping to `value` exists;
                `False` otherwise

        Raises
        - NullPointerException: if the specified value is null
        """
        ...


    def size(self) -> int:
        """

        """
        ...


    def isEmpty(self) -> bool:
        """

        """
        ...


    def clear(self) -> None:
        """
        Removes all of the mappings from this map.
        """
        ...


    def computeIfAbsent(self, key: "K", mappingFunction: "Function"["K", "V"]) -> "V":
        """
        If the specified key is not already associated with a value,
        attempts to compute its value using the given mapping function
        and enters it into this map unless `null`.  The function
        is *NOT* guaranteed to be applied once atomically only
        if the value is not present.

        Arguments
        - key: key with which the specified value is to be associated
        - mappingFunction: the function to compute a value

        Returns
        - the current (existing or computed) value associated with
                the specified key, or null if the computed value is null

        Raises
        - NullPointerException: if the specified key is null
                or the mappingFunction is null

        Since
        - 1.8
        """
        ...


    def computeIfPresent(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        If the value for the specified key is present, attempts to
        compute a new mapping given the key and its current mapped
        value. The function is *NOT* guaranteed to be applied
        once atomically.

        Arguments
        - key: key with which a value may be associated
        - remappingFunction: the function to compute a value

        Returns
        - the new value associated with the specified key, or null if none

        Raises
        - NullPointerException: if the specified key is null
                or the remappingFunction is null

        Since
        - 1.8
        """
        ...


    def compute(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        Attempts to compute a mapping for the specified key and its
        current mapped value (or `null` if there is no current
        mapping). The function is *NOT* guaranteed to be applied
        once atomically.

        Arguments
        - key: key with which the specified value is to be associated
        - remappingFunction: the function to compute a value

        Returns
        - the new value associated with the specified key, or null if none

        Raises
        - NullPointerException: if the specified key is null
                or the remappingFunction is null

        Since
        - 1.8
        """
        ...


    def merge(self, key: "K", value: "V", remappingFunction: "BiFunction"["V", "V", "V"]) -> "V":
        """
        If the specified key is not already associated with a value,
        associates it with the given value.  Otherwise, replaces the
        value with the results of the given remapping function, or
        removes if `null`. The function is *NOT*
        guaranteed to be applied once atomically.

        Arguments
        - key: key with which the specified value is to be associated
        - value: the value to use if absent
        - remappingFunction: the function to recompute a value if present

        Returns
        - the new value associated with the specified key, or null if none

        Raises
        - NullPointerException: if the specified key or value is null
                or the remappingFunction is null

        Since
        - 1.8
        """
        ...


    def keySet(self) -> "NavigableSet"["K"]:
        """
        Returns a NavigableSet view of the keys contained in this map.
        
        The set's iterator returns the keys in ascending order.
        The set's spliterator additionally reports Spliterator.CONCURRENT,
        Spliterator.NONNULL, Spliterator.SORTED and
        Spliterator.ORDERED, with an encounter order that is ascending
        key order.
        
        The Spliterator.getComparator() spliterator's comparator
        is `null` if the .comparator() map's comparator
        is `null`.
        Otherwise, the spliterator's comparator is the same as or imposes the
        same total ordering as the map's comparator.
        
        The set is backed by the map, so changes to the map are
        reflected in the set, and vice-versa.  The set supports element
        removal, which removes the corresponding mapping from the map,
        via the `Iterator.remove`, `Set.remove`,
        `removeAll`, `retainAll`, and `clear`
        operations.  It does not support the `add` or `addAll`
        operations.
        
        The view's iterators and spliterators are
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        
        This method is equivalent to method `navigableKeySet`.

        Returns
        - a navigable set view of the keys in this map
        """
        ...


    def navigableKeySet(self) -> "NavigableSet"["K"]:
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a Collection view of the values contained in this map.
        The collection's iterator returns the values in ascending order
        of the corresponding keys. The collections's spliterator additionally
        reports Spliterator.CONCURRENT, Spliterator.NONNULL and
        Spliterator.ORDERED, with an encounter order that is ascending
        order of the corresponding keys.
        
        The collection is backed by the map, so changes to the map are
        reflected in the collection, and vice-versa.  The collection
        supports element removal, which removes the corresponding
        mapping from the map, via the `Iterator.remove`,
        `Collection.remove`, `removeAll`,
        `retainAll` and `clear` operations.  It does not
        support the `add` or `addAll` operations.
        
        The view's iterators and spliterators are
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        """
        ...


    def entrySet(self) -> set["Map.Entry"["K", "V"]]:
        """
        Returns a Set view of the mappings contained in this map.
        
        The set's iterator returns the entries in ascending key order.  The
        set's spliterator additionally reports Spliterator.CONCURRENT,
        Spliterator.NONNULL, Spliterator.SORTED and
        Spliterator.ORDERED, with an encounter order that is ascending
        key order.
        
        The set is backed by the map, so changes to the map are
        reflected in the set, and vice-versa.  The set supports element
        removal, which removes the corresponding mapping from the map,
        via the `Iterator.remove`, `Set.remove`,
        `removeAll`, `retainAll` and `clear`
        operations.  It does not support the `add` or
        `addAll` operations.
        
        The view's iterators and spliterators are
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        
        The `Map.Entry` elements traversed by the `iterator`
        or `spliterator` do *not* support the `setValue`
        operation.

        Returns
        - a set view of the mappings contained in this map,
                sorted in ascending key order
        """
        ...


    def descendingMap(self) -> "ConcurrentNavigableMap"["K", "V"]:
        ...


    def descendingKeySet(self) -> "NavigableSet"["K"]:
        ...


    def equals(self, o: "Object") -> bool:
        """
        Compares the specified object with this map for equality.
        Returns `True` if the given object is also a map and the
        two maps represent the same mappings.  More formally, two maps
        `m1` and `m2` represent the same mappings if
        `m1.entrySet().equals(m2.entrySet())`.  This
        operation may return misleading results if either map is
        concurrently modified during execution of this method.

        Arguments
        - o: object to be compared for equality with this map

        Returns
        - `True` if the specified object is equal to this map
        """
        ...


    def putIfAbsent(self, key: "K", value: "V") -> "V":
        """
        Returns
        - the previous value associated with the specified key,
                or `null` if there was no mapping for the key

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key or value is null
        """
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        """
        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key is null
        """
        ...


    def replace(self, key: "K", oldValue: "V", newValue: "V") -> bool:
        """
        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if any of the arguments are null
        """
        ...


    def replace(self, key: "K", value: "V") -> "V":
        """
        Returns
        - the previous value associated with the specified key,
                or `null` if there was no mapping for the key

        Raises
        - ClassCastException: if the specified key cannot be compared
                with the keys currently in the map
        - NullPointerException: if the specified key or value is null
        """
        ...


    def comparator(self) -> "Comparator"["K"]:
        ...


    def firstKey(self) -> "K":
        """
        Raises
        - NoSuchElementException: 
        """
        ...


    def lastKey(self) -> "K":
        """
        Raises
        - NoSuchElementException: 
        """
        ...


    def subMap(self, fromKey: "K", fromInclusive: bool, toKey: "K", toInclusive: bool) -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `fromKey` or `toKey` is null
        - IllegalArgumentException: 
        """
        ...


    def headMap(self, toKey: "K", inclusive: bool) -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `toKey` is null
        - IllegalArgumentException: 
        """
        ...


    def tailMap(self, fromKey: "K", inclusive: bool) -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `fromKey` is null
        - IllegalArgumentException: 
        """
        ...


    def subMap(self, fromKey: "K", toKey: "K") -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `fromKey` or `toKey` is null
        - IllegalArgumentException: 
        """
        ...


    def headMap(self, toKey: "K") -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `toKey` is null
        - IllegalArgumentException: 
        """
        ...


    def tailMap(self, fromKey: "K") -> "ConcurrentNavigableMap"["K", "V"]:
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if `fromKey` is null
        - IllegalArgumentException: 
        """
        ...


    def lowerEntry(self, key: "K") -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the greatest key
        strictly less than the given key, or `null` if there is
        no such key. The returned entry does *not* support the
        `Entry.setValue` method.

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def lowerKey(self, key: "K") -> "K":
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def floorEntry(self, key: "K") -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the greatest key
        less than or equal to the given key, or `null` if there
        is no such key. The returned entry does *not* support
        the `Entry.setValue` method.

        Arguments
        - key: the key

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def floorKey(self, key: "K") -> "K":
        """
        Arguments
        - key: the key

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def ceilingEntry(self, key: "K") -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the least key
        greater than or equal to the given key, or `null` if
        there is no such entry. The returned entry does *not*
        support the `Entry.setValue` method.

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def ceilingKey(self, key: "K") -> "K":
        """
        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def higherEntry(self, key: "K") -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the least key
        strictly greater than the given key, or `null` if there
        is no such key. The returned entry does *not* support
        the `Entry.setValue` method.

        Arguments
        - key: the key

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def higherKey(self, key: "K") -> "K":
        """
        Arguments
        - key: the key

        Raises
        - ClassCastException: 
        - NullPointerException: if the specified key is null
        """
        ...


    def firstEntry(self) -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the least
        key in this map, or `null` if the map is empty.
        The returned entry does *not* support
        the `Entry.setValue` method.
        """
        ...


    def lastEntry(self) -> "Map.Entry"["K", "V"]:
        """
        Returns a key-value mapping associated with the greatest
        key in this map, or `null` if the map is empty.
        The returned entry does *not* support
        the `Entry.setValue` method.
        """
        ...


    def pollFirstEntry(self) -> "Map.Entry"["K", "V"]:
        """
        Removes and returns a key-value mapping associated with
        the least key in this map, or `null` if the map is empty.
        The returned entry does *not* support
        the `Entry.setValue` method.
        """
        ...


    def pollLastEntry(self) -> "Map.Entry"["K", "V"]:
        """
        Removes and returns a key-value mapping associated with
        the greatest key in this map, or `null` if the map is empty.
        The returned entry does *not* support
        the `Entry.setValue` method.
        """
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.ArmorMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory.meta import *
from org.bukkit.inventory.meta.trim import ArmorTrim
from typing import Any, Callable, Iterable, Tuple


class ArmorMeta(ItemMeta):
    """
    Represents armor that an entity can equip.
    
    <strong>Note: Armor trims are part of an experimental feature of Minecraft
    and hence subject to change.</strong>
    """

    def hasTrim(self) -> bool:
        """
        Check whether or not this item has an armor trim.

        Returns
        - True if has a trim, False otherwise
        """
        ...


    def setTrim(self, trim: "ArmorTrim") -> None:
        """
        Set the ArmorTrim.

        Arguments
        - trim: the trim to set, or null to remove it
        """
        ...


    def getTrim(self) -> "ArmorTrim":
        """
        Get the ArmorTrim.

        Returns
        - the armor trim, or null if none
        """
        ...


    def clone(self) -> "ArmorMeta":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerSwapHandItemsEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerSwapHandItemsEvent(PlayerEvent, Cancellable):
    """
    Called when a player swap items between main hand and off hand using the
    hotkey.
    """

    def __init__(self, player: "Player", mainHandItem: "ItemStack", offHandItem: "ItemStack"):
        ...


    def getMainHandItem(self) -> "ItemStack":
        """
        Gets the item switched to the main hand.

        Returns
        - item in the main hand
        """
        ...


    def setMainHandItem(self, mainHandItem: "ItemStack") -> None:
        """
        Sets the item in the main hand.

        Arguments
        - mainHandItem: new item in the main hand
        """
        ...


    def getOffHandItem(self) -> "ItemStack":
        """
        Gets the item switched to the off hand.

        Returns
        - item in the off hand
        """
        ...


    def setOffHandItem(self, offHandItem: "ItemStack") -> None:
        """
        Sets the item in the off hand.

        Arguments
        - offHandItem: new item in the off hand
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.SortedMultisetBridge

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from java.util import SortedSet
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SortedMultisetBridge(Multiset):
    """
    Superinterface of SortedMultiset to introduce a bridge method for `elementSet()`,
    to ensure binary compatibility with older Guava versions that specified `elementSet()` to
    return `SortedSet`.

    Author(s)
    - Louis Wasserman
    """

    def elementSet(self) -> "SortedSet"["E"]:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockDamageEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class BlockDamageEvent(BlockEvent, Cancellable):
    """
    Called when a block is damaged by a player.
    
    If a Block Damage event is cancelled, the block will not be damaged.

    See
    - BlockDamageAbortEvent
    """

    def __init__(self, player: "Player", block: "Block", itemInHand: "ItemStack", instaBreak: bool):
        ...


    def getPlayer(self) -> "Player":
        """
        Gets the player damaging the block involved in this event.

        Returns
        - The player damaging the block involved in this event
        """
        ...


    def getInstaBreak(self) -> bool:
        """
        Gets if the block is set to instantly break when damaged by the player.

        Returns
        - True if the block should instantly break when damaged by the
            player
        """
        ...


    def setInstaBreak(self, bool: bool) -> None:
        """
        Sets if the block should instantly break when damaged by the player.

        Arguments
        - bool: True if you want the block to instantly break when damaged
            by the player
        """
        ...


    def getItemInHand(self) -> "ItemStack":
        """
        Gets the ItemStack for the item currently in the player's hand.

        Returns
        - The ItemStack for the item currently in the player's hand
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.function.Consumer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class Consumer:
    """
    Represents an operation that accepts a single input argument and returns no
    result. Unlike most other functional interfaces, `Consumer` is expected
    to operate via side-effects.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .accept(Object).
    
    Type `<T>`: the type of the input to the operation

    Since
    - 1.8
    """

    def accept(self, t: "T") -> None:
        """
        Performs this operation on the given argument.

        Arguments
        - t: the input argument
        """
        ...


    def andThen(self, after: "Consumer"["T"]) -> "Consumer"["T"]:
        """
        Returns a composed `Consumer` that performs, in sequence, this
        operation followed by the `after` operation. If performing either
        operation throws an exception, it is relayed to the caller of the
        composed operation.  If performing this operation throws an exception,
        the `after` operation will not be performed.

        Arguments
        - after: the operation to perform after this operation

        Returns
        - a composed `Consumer` that performs in sequence this
        operation followed by the `after` operation

        Raises
        - NullPointerException: if `after` is null
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.InventoryCreativeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event.inventory import *
from org.bukkit.event.inventory.InventoryType import SlotType
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class InventoryCreativeEvent(InventoryClickEvent):
    """
    This event is called when a player in creative mode puts down or picks up
    an item in their inventory / hotbar and when they drop items from their
    Inventory while in creative mode.
    """

    def __init__(self, what: "InventoryView", type: "SlotType", slot: int, newItem: "ItemStack"):
        ...


    def getCursor(self) -> "ItemStack":
        ...


    def setCursor(self, item: "ItemStack") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.scheduler.BukkitWorker

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import Plugin
from org.bukkit.scheduler import *
from typing import Any, Callable, Iterable, Tuple


class BukkitWorker:
    """
    Represents a worker thread for the scheduler. This gives information about
    the Thread object for the task, owner of the task and the taskId.
    
    Workers are used to execute async tasks.
    """

    def getTaskId(self) -> int:
        """
        Returns the taskId for the task being executed by this worker.

        Returns
        - Task id number
        """
        ...


    def getOwner(self) -> "Plugin":
        """
        Returns the Plugin that owns this task.

        Returns
        - The Plugin that owns the task
        """
        ...


    def getThread(self) -> "Thread":
        """
        Returns the thread for the worker.

        Returns
        - The Thread object for the worker
        """
        ...



"""
Python module generated from Java source file java.io.BufferedWriter

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class BufferedWriter(Writer):

    def __init__(self, out: "Writer"):
        """
        Creates a buffered character-output stream that uses a default-sized
        output buffer.

        Arguments
        - out: A Writer
        """
        ...


    def __init__(self, out: "Writer", sz: int):
        """
        Creates a new buffered character-output stream that uses an output
        buffer of the given size.

        Arguments
        - out: A Writer
        - sz: Output-buffer size, a positive integer

        Raises
        - IllegalArgumentException: If `sz <= 0`
        """
        ...


    def write(self, c: int) -> None:
        """
        Writes a single character.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, cbuf: list[str], off: int, len: int) -> None:
        """
        Writes a portion of an array of characters.
        
         Ordinarily this method stores characters from the given array into
        this stream's buffer, flushing the buffer to the underlying stream as
        needed.  If the requested length is at least as large as the buffer,
        however, then this method will flush the buffer and write the characters
        directly to the underlying stream.  Thus redundant
        `BufferedWriter`s will not copy data unnecessarily.

        Arguments
        - cbuf: A character array
        - off: Offset from which to start reading characters
        - len: Number of characters to write

        Raises
        - IndexOutOfBoundsException: If `off` is negative, or `len` is negative,
                 or `off + len` is negative or greater than the length
                 of the given array
        - IOException: If an I/O error occurs
        """
        ...


    def write(self, s: str, off: int, len: int) -> None:
        """
        Writes a portion of a String.

        Arguments
        - s: String to be written
        - off: Offset from which to start reading characters
        - len: Number of characters to be written

        Raises
        - IndexOutOfBoundsException: If `off` is negative,
                 or `off + len` is greater than the length
                 of the given string
        - IOException: If an I/O error occurs

        Unknown Tags
        - While the specification of this method in the
        java.io.Writer.write(java.lang.String,int,int) superclass
        recommends that an IndexOutOfBoundsException be thrown
        if `len` is negative or `off + len` is negative,
        the implementation in this class does not throw such an exception in
        these cases but instead simply writes no characters.
        """
        ...


    def newLine(self) -> None:
        """
        Writes a line separator.  The line separator string is defined by the
        system property `line.separator`, and is not necessarily a single
        newline ('\n') character.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def flush(self) -> None:
        """
        Flushes the stream.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file java.io.DataInputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class DataInputStream(FilterInputStream, DataInput):
    """
    A data input stream lets an application read primitive Java data
    types from an underlying input stream in a machine-independent
    way. An application uses a data output stream to write data that
    can later be read by a data input stream.
    
    A DataInputStream is not safe for use by multiple concurrent
    threads. If a DataInputStream is to be used by more than one
    thread then access to the data input stream should be controlled
    by appropriate synchronization.

    Author(s)
    - Arthur van Hoff

    See
    - java.io.DataOutputStream

    Since
    - 1.0
    """

    def __init__(self, in: "InputStream"):
        """
        Creates a DataInputStream that uses the specified
        underlying InputStream.

        Arguments
        - in: the specified input stream
        """
        ...


    def read(self, b: list[int]) -> int:
        """
        Reads some number of bytes from the contained input stream and
        stores them into the buffer array `b`. The number of
        bytes actually read is returned as an integer. This method blocks
        until input data is available, end of file is detected, or an
        exception is thrown.
        
        If `b` is null, a `NullPointerException` is
        thrown. If the length of `b` is zero, then no bytes are
        read and `0` is returned; otherwise, there is an attempt
        to read at least one byte. If no byte is available because the
        stream is at end of file, the value `-1` is returned;
        otherwise, at least one byte is read and stored into `b`.
        
        The first byte read is stored into element `b[0]`, the
        next one into `b[1]`, and so on. The number of bytes read
        is, at most, equal to the length of `b`. Let `k`
        be the number of bytes actually read; these bytes will be stored in
        elements `b[0]` through `b[k-1]`, leaving
        elements `b[k]` through `b[b.length-1]`
        unaffected.
        
        The `read(b)` method has the same effect as:
        <blockquote>```
        read(b, 0, b.length)
        ```</blockquote>

        Arguments
        - b: the buffer into which the data is read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end
                    of the stream has been reached.

        Raises
        - IOException: if the first byte cannot be read for any reason
                    other than end of file, the stream has been closed and the underlying
                    input stream does not support reading after close, or another I/O
                    error occurs.

        See
        - java.io.InputStream.read(byte[], int, int)
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads up to `len` bytes of data from the contained
        input stream into an array of bytes.  An attempt is made to read
        as many as `len` bytes, but a smaller number may be read,
        possibly zero. The number of bytes actually read is returned as an
        integer.
        
         This method blocks until input data is available, end of file is
        detected, or an exception is thrown.
        
         If `len` is zero, then no bytes are read and
        `0` is returned; otherwise, there is an attempt to read at
        least one byte. If no byte is available because the stream is at end of
        file, the value `-1` is returned; otherwise, at least one
        byte is read and stored into `b`.
        
         The first byte read is stored into element `b[off]`, the
        next one into `b[off+1]`, and so on. The number of bytes read
        is, at most, equal to `len`. Let *k* be the number of
        bytes actually read; these bytes will be stored in elements
        `b[off]` through `b[off+`*k*`-1]`,
        leaving elements `b[off+`*k*`]` through
        `b[off+len-1]` unaffected.
        
         In every case, elements `b[0]` through
        `b[off]` and elements `b[off+len]` through
        `b[b.length-1]` are unaffected.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in the destination array `b`
        - len: the maximum number of bytes read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end
                    of the stream has been reached.

        Raises
        - NullPointerException: If `b` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`
        - IOException: if the first byte cannot be read for any reason
                    other than end of file, the stream has been closed and the underlying
                    input stream does not support reading after close, or another I/O
                    error occurs.

        See
        - java.io.InputStream.read(byte[], int, int)
        """
        ...


    def readFully(self, b: list[int]) -> None:
        """
        See the general contract of the `readFully`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Arguments
        - b: the buffer into which the data is read.

        Raises
        - NullPointerException: if `b` is `null`.
        - EOFException: if this input stream reaches the end before
                 reading all the bytes.
        - IOException: the stream has been closed and the contained
                 input stream does not support reading after close, or
                 another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readFully(self, b: list[int], off: int, len: int) -> None:
        """
        See the general contract of the `readFully`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in the data array `b`.
        - len: the number of bytes to read.

        Raises
        - NullPointerException: if `b` is `null`.
        - IndexOutOfBoundsException: if `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`.
        - EOFException: if this input stream reaches the end before
                    reading all the bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def skipBytes(self, n: int) -> int:
        """
        See the general contract of the `skipBytes`
        method of `DataInput`.
        
        Bytes for this operation are read from the contained
        input stream.

        Arguments
        - n: the number of bytes to be skipped.

        Returns
        - the actual number of bytes skipped.

        Raises
        - IOException: if the contained input stream does not support
                    seek, or the stream has been closed and
                    the contained input stream does not support
                    reading after close, or another I/O error occurs.
        """
        ...


    def readBoolean(self) -> bool:
        """
        See the general contract of the `readBoolean`
        method of `DataInput`.
        
        Bytes for this operation are read from the contained
        input stream.

        Returns
        - the `boolean` value read.

        Raises
        - EOFException: if this input stream has reached the end.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readByte(self) -> int:
        """
        See the general contract of the `readByte`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next byte of this input stream as a signed 8-bit
                    `byte`.

        Raises
        - EOFException: if this input stream has reached the end.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readUnsignedByte(self) -> int:
        """
        See the general contract of the `readUnsignedByte`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next byte of this input stream, interpreted as an
                    unsigned 8-bit number.

        Raises
        - EOFException: if this input stream has reached the end.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readShort(self) -> int:
        """
        See the general contract of the `readShort`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next two bytes of this input stream, interpreted as a
                    signed 16-bit number.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading two bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readUnsignedShort(self) -> int:
        """
        See the general contract of the `readUnsignedShort`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next two bytes of this input stream, interpreted as an
                    unsigned 16-bit integer.

        Raises
        - EOFException: if this input stream reaches the end before
                    reading two bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readChar(self) -> str:
        """
        See the general contract of the `readChar`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next two bytes of this input stream, interpreted as a
                    `char`.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading two bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readInt(self) -> int:
        """
        See the general contract of the `readInt`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next four bytes of this input stream, interpreted as an
                    `int`.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading four bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readLong(self) -> int:
        """
        See the general contract of the `readLong`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next eight bytes of this input stream, interpreted as a
                    `long`.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading eight bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def readFloat(self) -> float:
        """
        See the general contract of the `readFloat`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next four bytes of this input stream, interpreted as a
                    `float`.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading four bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.lang.Float.intBitsToFloat(int)
        """
        ...


    def readDouble(self) -> float:
        """
        See the general contract of the `readDouble`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next eight bytes of this input stream, interpreted as a
                    `double`.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading eight bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.

        See
        - java.lang.Double.longBitsToDouble(long)
        """
        ...


    def readLine(self) -> str:
        """
        See the general contract of the `readLine`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - the next line of text from this input stream.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FilterInputStream.in

        Deprecated
        - This method does not properly convert bytes to characters.
        As of JDK&nbsp;1.1, the preferred way to read lines of text is via the
        `BufferedReader.readLine()` method.  Programs that use the
        `DataInputStream` class to read lines can be converted to use
        the `BufferedReader` class by replacing code of the form:
        <blockquote>```
            DataInputStream d =&nbsp;new&nbsp;DataInputStream(in);
        ```</blockquote>
        with:
        <blockquote>```
            BufferedReader d
                 =&nbsp;new&nbsp;BufferedReader(new&nbsp;InputStreamReader(in));
        ```</blockquote>
        """
        ...


    def readUTF(self) -> str:
        """
        See the general contract of the `readUTF`
        method of `DataInput`.
        
        Bytes
        for this operation are read from the contained
        input stream.

        Returns
        - a Unicode string.

        Raises
        - EOFException: if this input stream reaches the end before
                      reading all the bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.
        - UTFDataFormatException: if the bytes do not represent a valid
                    modified UTF-8 encoding of a string.

        See
        - java.io.DataInputStream.readUTF(java.io.DataInput)
        """
        ...


    @staticmethod
    def readUTF(in: "DataInput") -> str:
        """
        Reads from the
        stream `in` a representation
        of a Unicode  character string encoded in
        <a href="DataInput.html#modified-utf-8">modified UTF-8</a> format;
        this string of characters is then returned as a `String`.
        The details of the modified UTF-8 representation
        are  exactly the same as for the `readUTF`
        method of `DataInput`.

        Arguments
        - in: a data input stream.

        Returns
        - a Unicode string.

        Raises
        - EOFException: if the input stream reaches the end
                      before all the bytes.
        - IOException: the stream has been closed and the contained
                    input stream does not support reading after close, or
                    another I/O error occurs.
        - UTFDataFormatException: if the bytes do not represent a
                      valid modified UTF-8 encoding of a Unicode string.

        See
        - java.io.DataInputStream.readUnsignedShort()
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.HoverEvent

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from java.util import Collections
from net.md_5.bungee.api.chat import *
from net.md_5.bungee.api.chat.hover.content import Content
from net.md_5.bungee.api.chat.hover.content import Entity
from net.md_5.bungee.api.chat.hover.content import Item
from net.md_5.bungee.api.chat.hover.content import Text
from net.md_5.bungee.chat import ComponentSerializer
from typing import Any, Callable, Iterable, Tuple


class HoverEvent:

    def __init__(self, action: "Action", *contents: Tuple["Content", ...]):
        """
        Creates event with an action and a list of contents.

        Arguments
        - action: action of this event
        - contents: array of contents, provide at least one
        """
        ...


    def __init__(self, action: "Action", value: list["BaseComponent"]):
        """
        Legacy constructor to create hover event.

        Arguments
        - action: the action
        - value: the value

        Deprecated
        - .HoverEvent(Action, Content[])
        """
        ...


    def getValue(self) -> list["BaseComponent"]:
        ...


    def addContent(self, content: "Content") -> None:
        """
        Adds a content to this hover event.

        Arguments
        - content: the content add

        Raises
        - IllegalArgumentException: if is a legacy component and already has
        a content
        - UnsupportedOperationException: if content action does not match
        hover event action
        """
        ...


    @staticmethod
    def getClass(action: "HoverEvent.Action", array: bool) -> type[Any]:
        """
        Gets the appropriate Content class for an Action for the
        GSON serialization

        Arguments
        - action: the action to get for
        - array: if to return the arrayed class

        Returns
        - the class
        """
        ...


    class Action(Enum):

        SHOW_TEXT = 0
        SHOW_ITEM = 1
        SHOW_ENTITY = 2
        SHOW_ACHIEVEMENT = 3
        """
        Removed since 1.12. Advancements instead simply use show_text. The ID
        of an achievement or statistic to display. Example: new
        ComponentText( "achievement.openInventory" )
        """



"""
Python module generated from Java source file com.google.common.graph.MapIteratorCache

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import UnmodifiableIterator
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import AbstractSet
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MapIteratorCache:
    """
    A map-like data structure that wraps a backing map and caches values while iterating through
    .unmodifiableKeySet(). By design, the cache is cleared when this structure is mutated. If
    this structure is never mutated, it provides a thread-safe view of the backing map.
    
    The MapIteratorCache assumes ownership of the backing map, and cannot guarantee
    correctness in the face of external mutations to the backing map. As such, it is **strongly**
    recommended that the caller does not persist a reference to the backing map (unless the backing
    map is immutable).
    
    This class is tailored toward use cases in common.graph. It is *NOT* a general purpose map.

    Author(s)
    - James Sexton
    """





"""
Python module generated from Java source file org.bukkit.entity.Pose

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Pose(Enum):
    """
    Represents an entity body pose.
    """

    STANDING = 0
    """
    Entity is standing normally.
    """
    FALL_FLYING = 1
    """
    Entity is gliding.
    """
    SLEEPING = 2
    """
    Entity is sleeping.
    """
    SWIMMING = 3
    """
    Entity is swimming.
    """
    SPIN_ATTACK = 4
    """
    Entity is riptiding with a trident.
    """
    SNEAKING = 5
    """
    Entity is sneaking.
    """
    LONG_JUMPING = 6
    """
    Entity is long jumping.
    """
    DYING = 7
    """
    Entity is dead.
    """
    CROAKING = 8
    """
    Entity is croaking.
    """
    USING_TONGUE = 9
    """
    Entity is using its tongue.
    """
    SITTING = 10
    """
    Entity is sitting.
    """
    ROARING = 11
    """
    Entity is roaring.
    """
    SNIFFING = 12
    """
    Entity is sniffing.
    """
    EMERGING = 13
    """
    Entity is emerging.
    """
    DIGGING = 14
    """
    Entity is digging.
    """
    SLIDING = 15
    """
    Entity is sliding.
    """
    SHOOTING = 16
    """
    Entity is shooting.
    """
    INHALING = 17
    """
    Entity is inhaling.
    """



"""
Python module generated from Java source file org.bukkit.persistence.ListPersistentDataTypeProvider

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Collections2
from com.google.common.collect import Lists
from org.bukkit.persistence import *
from typing import Any, Callable, Iterable, Tuple


class ListPersistentDataTypeProvider:
    """
    A provider for list persistent data types that represent the known primitive
    types exposed by PersistentDataType.
    """

    def bytes(self) -> "ListPersistentDataType"["Byte", "Byte"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of bytes.

        Returns
        - the persistent data type.
        """
        ...


    def shorts(self) -> "ListPersistentDataType"["Short", "Short"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of shorts.

        Returns
        - the persistent data type.
        """
        ...


    def integers(self) -> "ListPersistentDataType"["Integer", "Integer"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of integers.

        Returns
        - the persistent data type.
        """
        ...


    def longs(self) -> "ListPersistentDataType"["Long", "Long"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of longs.

        Returns
        - the persistent data type.
        """
        ...


    def floats(self) -> "ListPersistentDataType"["Float", "Float"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of floats.

        Returns
        - the persistent data type.
        """
        ...


    def doubles(self) -> "ListPersistentDataType"["Double", "Double"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of doubles.

        Returns
        - the persistent data type.
        """
        ...


    def booleans(self) -> "ListPersistentDataType"["Byte", "Boolean"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of booleans.

        Returns
        - the persistent data type.
        """
        ...


    def strings(self) -> "ListPersistentDataType"[str, str]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of strings.

        Returns
        - the persistent data type.
        """
        ...


    def byteArrays(self) -> "ListPersistentDataType"[list[int], list[int]]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of byte arrays.

        Returns
        - the persistent data type.
        """
        ...


    def integerArrays(self) -> "ListPersistentDataType"[list[int], list[int]]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of int arrays.

        Returns
        - the persistent data type.
        """
        ...


    def longArrays(self) -> "ListPersistentDataType"[list[int], list[int]]:
        """
        Provides a shared ListPersistentDataType that is capable of
        storing lists of long arrays.

        Returns
        - the persistent data type.
        """
        ...


    def dataContainers(self) -> "ListPersistentDataType"["PersistentDataContainer", "PersistentDataContainer"]:
        """
        Provides a shared ListPersistentDataType that is capable of
        persistent data containers..

        Returns
        - the persistent data type.
        """
        ...


    def listTypeFrom(self, elementType: "PersistentDataType"["P", "C"]) -> "ListPersistentDataType"["P", "C"]:
        """
        Constructs a new list persistent data type given any persistent data type
        for its elements.
        
        Type `<P>`: the generic type of the primitives stored in the list.
        
        Type `<C>`: the generic type of the complex values yielded back by the
        persistent data types.

        Arguments
        - elementType: the persistent data type that is capable of
        writing/reading the elements of the list.

        Returns
        - the created list persistent data type.
        """
        ...



"""
Python module generated from Java source file java.util.PriorityQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from java.util.function import Consumer
from java.util.function import Predicate
from jdk.internal.access import SharedSecrets
from jdk.internal.util import ArraysSupport
from typing import Any, Callable, Iterable, Tuple


class PriorityQueue(AbstractQueue, Serializable):
    """
    An unbounded priority Queue queue based on a priority heap.
    The elements of the priority queue are ordered according to their
    Comparable natural ordering, or by a Comparator
    provided at queue construction time, depending on which constructor is
    used.  A priority queue does not permit `null` elements.
    A priority queue relying on natural ordering also does not permit
    insertion of non-comparable objects (doing so may result in
    `ClassCastException`).
    
    The *head* of this queue is the *least* element
    with respect to the specified ordering.  If multiple elements are
    tied for least value, the head is one of those elements -- ties are
    broken arbitrarily.  The queue retrieval operations `poll`,
    `remove`, `peek`, and `element` access the
    element at the head of the queue.
    
    A priority queue is unbounded, but has an internal
    *capacity* governing the size of an array used to store the
    elements on the queue.  It is always at least as large as the queue
    size.  As elements are added to a priority queue, its capacity
    grows automatically.  The details of the growth policy are not
    specified.
    
    This class and its iterator implement all of the
    *optional* methods of the Collection and Iterator interfaces.  The Iterator provided in method .iterator() and the Spliterator provided in method .spliterator()
    are *not* guaranteed to traverse the elements of
    the priority queue in any particular order. If you need ordered
    traversal, consider using `Arrays.sort(pq.toArray())`.
    
    <strong>Note that this implementation is not synchronized.</strong>
    Multiple threads should not access a `PriorityQueue`
    instance concurrently if any of the threads modifies the queue.
    Instead, use the thread-safe java.util.concurrent.PriorityBlockingQueue class.
    
    Implementation note: this implementation provides
    O(log(n)) time for the enqueuing and dequeuing methods
    (`offer`, `poll`, `remove()` and `add`);
    linear time for the `remove(Object)` and `contains(Object)`
    methods; and constant time for the retrieval methods
    (`peek`, `element`, and `size`).
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Josh Bloch, Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a `PriorityQueue` with the default initial
        capacity (11) that orders its elements according to their
        Comparable natural ordering.
        """
        ...


    def __init__(self, initialCapacity: int):
        """
        Creates a `PriorityQueue` with the specified initial
        capacity that orders its elements according to their
        Comparable natural ordering.

        Arguments
        - initialCapacity: the initial capacity for this priority queue

        Raises
        - IllegalArgumentException: if `initialCapacity` is less
                than 1
        """
        ...


    def __init__(self, comparator: "Comparator"["E"]):
        """
        Creates a `PriorityQueue` with the default initial capacity and
        whose elements are ordered according to the specified comparator.

        Arguments
        - comparator: the comparator that will be used to order this
                priority queue.  If `null`, the Comparable
                natural ordering of the elements will be used.

        Since
        - 1.8
        """
        ...


    def __init__(self, initialCapacity: int, comparator: "Comparator"["E"]):
        """
        Creates a `PriorityQueue` with the specified initial capacity
        that orders its elements according to the specified comparator.

        Arguments
        - initialCapacity: the initial capacity for this priority queue
        - comparator: the comparator that will be used to order this
                priority queue.  If `null`, the Comparable
                natural ordering of the elements will be used.

        Raises
        - IllegalArgumentException: if `initialCapacity` is
                less than 1
        """
        ...


    def __init__(self, c: Iterable["E"]):
        """
        Creates a `PriorityQueue` containing the elements in the
        specified collection.  If the specified collection is an instance of
        a SortedSet or is another `PriorityQueue`, this
        priority queue will be ordered according to the same ordering.
        Otherwise, this priority queue will be ordered according to the
        Comparable natural ordering of its elements.

        Arguments
        - c: the collection whose elements are to be placed
                into this priority queue

        Raises
        - ClassCastException: if elements of the specified collection
                cannot be compared to one another according to the priority
                queue's ordering
        - NullPointerException: if the specified collection or any
                of its elements are null
        """
        ...


    def __init__(self, c: "PriorityQueue"["E"]):
        """
        Creates a `PriorityQueue` containing the elements in the
        specified priority queue.  This priority queue will be
        ordered according to the same ordering as the given priority
        queue.

        Arguments
        - c: the priority queue whose elements are to be placed
                into this priority queue

        Raises
        - ClassCastException: if elements of `c` cannot be
                compared to one another according to `c`'s
                ordering
        - NullPointerException: if the specified priority queue or any
                of its elements are null
        """
        ...


    def __init__(self, c: "SortedSet"["E"]):
        """
        Creates a `PriorityQueue` containing the elements in the
        specified sorted set.   This priority queue will be ordered
        according to the same ordering as the given sorted set.

        Arguments
        - c: the sorted set whose elements are to be placed
                into this priority queue

        Raises
        - ClassCastException: if elements of the specified sorted
                set cannot be compared to one another according to the
                sorted set's ordering
        - NullPointerException: if the specified sorted set or any
                of its elements are null
        """
        ...


    def add(self, e: "E") -> bool:
        """
        Inserts the specified element into this priority queue.

        Returns
        - `True` (as specified by Collection.add)

        Raises
        - ClassCastException: if the specified element cannot be
                compared with elements currently in this priority queue
                according to the priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element into this priority queue.

        Returns
        - `True` (as specified by Queue.offer)

        Raises
        - ClassCastException: if the specified element cannot be
                compared with elements currently in this priority queue
                according to the priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def peek(self) -> "E":
        ...


    def remove(self, o: "Object") -> bool:
        """
        Removes a single instance of the specified element from this queue,
        if it is present.  More formally, removes an element `e` such
        that `o.equals(e)`, if this queue contains one or more such
        elements.  Returns `True` if and only if this queue contained
        the specified element (or equivalently, if this queue changed as a
        result of the call).

        Arguments
        - o: element to be removed from this queue, if present

        Returns
        - `True` if this queue changed as a result of the call
        """
        ...


    def contains(self, o: "Object") -> bool:
        """
        Returns `True` if this queue contains the specified element.
        More formally, returns `True` if and only if this queue contains
        at least one element `e` such that `o.equals(e)`.

        Arguments
        - o: object to be checked for containment in this queue

        Returns
        - `True` if this queue contains the specified element
        """
        ...


    def toArray(self) -> list["Object"]:
        """
        Returns an array containing all of the elements in this queue.
        The elements are in no particular order.
        
        The returned array will be "safe" in that no references to it are
        maintained by this queue.  (In other words, this method must allocate
        a new array).  The caller is thus free to modify the returned array.
        
        This method acts as bridge between array-based and collection-based
        APIs.

        Returns
        - an array containing all of the elements in this queue
        """
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        """
        Returns an array containing all of the elements in this queue; the
        runtime type of the returned array is that of the specified array.
        The returned array elements are in no particular order.
        If the queue fits in the specified array, it is returned therein.
        Otherwise, a new array is allocated with the runtime type of the
        specified array and the size of this queue.
        
        If the queue fits in the specified array with room to spare
        (i.e., the array has more elements than the queue), the element in
        the array immediately following the end of the collection is set to
        `null`.
        
        Like the .toArray() method, this method acts as bridge between
        array-based and collection-based APIs.  Further, this method allows
        precise control over the runtime type of the output array, and may,
        under certain circumstances, be used to save allocation costs.
        
        Suppose `x` is a queue known to contain only strings.
        The following code can be used to dump the queue into a newly
        allocated array of `String`:
        
        ``` `String[] y = x.toArray(new String[0]);````
        
        Note that `toArray(new Object[0])` is identical in function to
        `toArray()`.

        Arguments
        - a: the array into which the elements of the queue are to
                 be stored, if it is big enough; otherwise, a new array of the
                 same runtime type is allocated for this purpose.

        Returns
        - an array containing all of the elements in this queue

        Raises
        - ArrayStoreException: if the runtime type of the specified array
                is not a supertype of the runtime type of every element in
                this queue
        - NullPointerException: if the specified array is null
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an iterator over the elements in this queue. The iterator
        does not return the elements in any particular order.

        Returns
        - an iterator over the elements in this queue
        """
        ...


    def size(self) -> int:
        ...


    def clear(self) -> None:
        """
        Removes all of the elements from this priority queue.
        The queue will be empty after this call returns.
        """
        ...


    def poll(self) -> "E":
        ...


    def comparator(self) -> "Comparator"["E"]:
        """
        Returns the comparator used to order the elements in this
        queue, or `null` if this queue is sorted according to
        the Comparable natural ordering of its elements.

        Returns
        - the comparator used to order this queue, or
                `null` if this queue is sorted according to the
                natural ordering of its elements
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Creates a *<a href="Spliterator.html#binding">late-binding</a>*
        and *fail-fast* Spliterator over the elements in this
        queue. The spliterator does not traverse elements in any particular order
        (the Spliterator.ORDERED ORDERED characteristic is not reported).
        
        The `Spliterator` reports Spliterator.SIZED,
        Spliterator.SUBSIZED, and Spliterator.NONNULL.
        Overriding implementations should document the reporting of additional
        characteristic values.

        Returns
        - a `Spliterator` over the elements in this queue

        Since
        - 1.8
        """
        ...


    def removeIf(self, filter: "Predicate"["E"]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def retainAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def forEach(self, action: "Consumer"["E"]) -> None:
        """
        Raises
        - NullPointerException: 
        """
        ...



"""
Python module generated from Java source file com.google.common.primitives.SignedBytes

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from java.util import Arrays
from java.util import Comparator
from typing import Any, Callable, Iterable, Tuple


class SignedBytes:

    MAX_POWER_OF_TWO = 1 << 6
    """
    The largest power of two that can be represented as a signed `byte`.

    Since
    - 10.0
    """


    @staticmethod
    def checkedCast(value: int) -> int:
        """
        Returns the `byte` value that is equal to `value`, if possible.

        Arguments
        - value: any value in the range of the `byte` type

        Returns
        - the `byte` value that equals `value`

        Raises
        - IllegalArgumentException: if `value` is greater than Byte.MAX_VALUE or
            less than Byte.MIN_VALUE
        """
        ...


    @staticmethod
    def saturatedCast(value: int) -> int:
        """
        Returns the `byte` nearest in value to `value`.

        Arguments
        - value: any `long` value

        Returns
        - the same value cast to `byte` if it is in the range of the `byte` type,
            Byte.MAX_VALUE if it is too large, or Byte.MIN_VALUE if it is too small
        """
        ...


    @staticmethod
    def compare(a: int, b: int) -> int:
        """
        Compares the two specified `byte` values. The sign of the value returned is the same as
        that of `((Byte) a).compareTo(b)`.
        
        **Note:** this method behaves identically to the JDK 7 method Byte.compare.

        Arguments
        - a: the first `byte` to compare
        - b: the second `byte` to compare

        Returns
        - a negative value if `a` is less than `b`; a positive value if `a` is
            greater than `b`; or zero if they are equal
        """
        ...


    @staticmethod
    def min(*array: Tuple[int, ...]) -> int:
        """
        Returns the least value present in `array`.

        Arguments
        - array: a *nonempty* array of `byte` values

        Returns
        - the value present in `array` that is less than or equal to every other value in
            the array

        Raises
        - IllegalArgumentException: if `array` is empty
        """
        ...


    @staticmethod
    def max(*array: Tuple[int, ...]) -> int:
        """
        Returns the greatest value present in `array`.

        Arguments
        - array: a *nonempty* array of `byte` values

        Returns
        - the value present in `array` that is greater than or equal to every other value
            in the array

        Raises
        - IllegalArgumentException: if `array` is empty
        """
        ...


    @staticmethod
    def join(separator: str, *array: Tuple[int, ...]) -> str:
        """
        Returns a string containing the supplied `byte` values separated by `separator`.
        For example, `join(":", 0x01, 0x02, -0x01)` returns the string `"1:2:-1"`.

        Arguments
        - separator: the text that should appear between consecutive values in the resulting string
            (but not at the start or end)
        - array: an array of `byte` values, possibly empty
        """
        ...


    @staticmethod
    def lexicographicalComparator() -> "Comparator"[list[int]]:
        """
        Returns a comparator that compares two `byte` arrays <a
        href="http://en.wikipedia.org/wiki/Lexicographical_order">lexicographically</a>. That is, it
        compares, using .compare(byte, byte)), the first pair of values that follow any common
        prefix, or when one array is a prefix of the other, treats the shorter array as the lesser. For
        example, `[] < [0x01] < [0x01, 0x80] < [0x01, 0x7F] < [0x02]`. Values are treated as
        signed.
        
        The returned comparator is inconsistent with Object.equals(Object) (since arrays
        support only identity equality), but it is consistent with java.util.Arrays.equals(byte[], byte[]).

        Since
        - 2.0
        """
        ...


    @staticmethod
    def sortDescending(array: list[int]) -> None:
        """
        Sorts the elements of `array` in descending order.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def sortDescending(array: list[int], fromIndex: int, toIndex: int) -> None:
        """
        Sorts the elements of `array` between `fromIndex` inclusive and `toIndex`
        exclusive in descending order.

        Since
        - 23.1
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Splitter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.base import *
from java.util import Collections
from java.util import Iterator
from java.util.regex import Pattern
from java.util.stream import Stream
from java.util.stream import StreamSupport
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Splitter:
    """
    Extracts non-overlapping substrings from an input string, typically by recognizing appearances of
    a *separator* sequence. This separator can be specified as a single .on(char)
    character, fixed .on(String) string, .onPattern regular expression or
    .on(CharMatcher) CharMatcher instance. Or, instead of using a separator at all, a
    splitter can extract adjacent substrings of a given .fixedLength fixed length.
    
    For example, this expression:
    
    ````Splitter.on(',').split("foo,bar,qux")````
    
    ... produces an `Iterable` containing `"foo"`, `"bar"` and `"qux"`, in
    that order.
    
    By default, `Splitter`'s behavior is simplistic and unassuming. The following
    expression:
    
    ````Splitter.on(',').split(" foo,,,  bar ,")````
    
    ... yields the substrings `[" foo", "", "", " bar ", ""]`. If this is not the desired
    behavior, use configuration methods to obtain a *new* splitter instance with modified
    behavior:
    
    ````private static final Splitter MY_SPLITTER = Splitter.on(',')
        .trimResults()
        .omitEmptyStrings();````
    
    Now `MY_SPLITTER.split("foo,,, bar ,")` returns just `["foo", "bar"]`. Note that
    the order in which these configuration methods are called is never significant.
    
    **Warning:** Splitter instances are immutable. Invoking a configuration method has no
    effect on the receiving instance; you must store and use the new splitter instance it returns
    instead.
    
    ````// Do NOT do this
    Splitter splitter = Splitter.on('/');
    splitter.trimResults(); // does nothing!
    return splitter.split("wrong / wrong / wrong");````
    
    For separator-based splitters that do not use `omitEmptyStrings`, an input string
    containing `n` occurrences of the separator naturally yields an iterable of size `n +
    1`. So if the separator does not occur anywhere in the input, a single substring is returned
    containing the entire input. Consequently, all splitters split the empty string to `[""]`
    (note: even fixed-length splitters).
    
    Splitter instances are thread-safe immutable, and are therefore safe to store as `static
    final` constants.
    
    The Joiner class provides the inverse operation to splitting, but note that a
    round-trip between the two should be assumed to be lossy.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/StringsExplained#splitter">`Splitter`</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 1.0
    """

    @staticmethod
    def on(separator: str) -> "Splitter":
        """
        Returns a splitter that uses the given single-character separator. For example, `Splitter.on(',').split("foo,,bar")` returns an iterable containing `["foo", "", "bar"]`.

        Arguments
        - separator: the character to recognize as a separator

        Returns
        - a splitter, with default settings, that recognizes that separator
        """
        ...


    @staticmethod
    def on(separatorMatcher: "CharMatcher") -> "Splitter":
        """
        Returns a splitter that considers any single character matched by the given `CharMatcher`
        to be a separator. For example, `Splitter.on(CharMatcher.anyOf(";,")).split("foo,;bar,quux")` returns an iterable containing
        `["foo", "", "bar", "quux"]`.

        Arguments
        - separatorMatcher: a CharMatcher that determines whether a character is a
            separator

        Returns
        - a splitter, with default settings, that uses this matcher
        """
        ...


    @staticmethod
    def on(separator: str) -> "Splitter":
        """
        Returns a splitter that uses the given fixed string as a separator. For example, `Splitter.on(", ").split("foo, bar,baz")` returns an iterable containing `["foo",
        "bar,baz"]`.

        Arguments
        - separator: the literal, nonempty string to recognize as a separator

        Returns
        - a splitter, with default settings, that recognizes that separator
        """
        ...


    @staticmethod
    def on(separatorPattern: "Pattern") -> "Splitter":
        """
        Returns a splitter that considers any subsequence matching `pattern` to be a separator.
        For example, `Splitter.on(Pattern.compile("\r?\n")).split(entireFile)` splits a string
        into lines whether it uses DOS-style or UNIX-style line terminators.

        Arguments
        - separatorPattern: the pattern that determines whether a subsequence is a separator. This
            pattern may not match the empty string.

        Returns
        - a splitter, with default settings, that uses this pattern

        Raises
        - IllegalArgumentException: if `separatorPattern` matches the empty string
        """
        ...


    @staticmethod
    def onPattern(separatorPattern: str) -> "Splitter":
        """
        Returns a splitter that considers any subsequence matching a given pattern (regular expression)
        to be a separator. For example, `Splitter.onPattern("\r?\n").split(entireFile)` splits a
        string into lines whether it uses DOS-style or UNIX-style line terminators. This is equivalent
        to `Splitter.on(Pattern.compile(pattern))`.

        Arguments
        - separatorPattern: the pattern that determines whether a subsequence is a separator. This
            pattern may not match the empty string.

        Returns
        - a splitter, with default settings, that uses this pattern

        Raises
        - IllegalArgumentException: if `separatorPattern` matches the empty string or is a
            malformed expression
        """
        ...


    @staticmethod
    def fixedLength(length: int) -> "Splitter":
        """
        Returns a splitter that divides strings into pieces of the given length. For example, `Splitter.fixedLength(2).split("abcde")` returns an iterable containing `["ab", "cd",
        "e"]`. The last piece can be smaller than `length` but will never be empty.
        
        **Note:** if .fixedLength is used in conjunction with .limit, the final
        split piece *may be longer than the specified fixed length*. This is because the splitter
        will *stop splitting when the limit is reached*, and just return the final piece as-is.
        
        **Exception:** for consistency with separator-based splitters, `split("")` does not
        yield an empty iterable, but an iterable containing `""`. This is the only case in which
        `Iterables.size(split(input))` does not equal `IntMath.divide(input.length(),
        length, CEILING)`. To avoid this behavior, use `omitEmptyStrings`.

        Arguments
        - length: the desired length of pieces after splitting, a positive integer

        Returns
        - a splitter, with default settings, that can split into fixed sized pieces

        Raises
        - IllegalArgumentException: if `length` is zero or negative
        """
        ...


    def omitEmptyStrings(self) -> "Splitter":
        """
        Returns a splitter that behaves equivalently to `this` splitter, but automatically omits
        empty strings from the results. For example, `Splitter.on(',').omitEmptyStrings().split(",a,,,b,c,,")` returns an iterable containing only
        `["a", "b", "c"]`.
        
        If either `trimResults` option is also specified when creating a splitter, that
        splitter always trims results first before checking for emptiness. So, for example, `Splitter.on(':').omitEmptyStrings().trimResults().split(": : : ")` returns an empty iterable.
        
        Note that it is ordinarily not possible for .split(CharSequence) to return an empty
        iterable, but when using this option, it can (if the input sequence consists of nothing but
        separators).

        Returns
        - a splitter with the desired configuration
        """
        ...


    def limit(self, maxItems: int) -> "Splitter":
        """
        Returns a splitter that behaves equivalently to `this` splitter but stops splitting after
        it reaches the limit. The limit defines the maximum number of items returned by the iterator,
        or the maximum size of the list returned by .splitToList.
        
        For example, `Splitter.on(',').limit(3).split("a,b,c,d")` returns an iterable
        containing `["a", "b", "c,d"]`. When omitting empty strings, the omitted strings do not
        count. Hence, `Splitter.on(',').limit(3).omitEmptyStrings().split("a,,,b,,,c,d")` returns
        an iterable containing `["a", "b", "c,d"]`. When trim is requested, all entries are
        trimmed, including the last. Hence `Splitter.on(',').limit(3).trimResults().split(" a , b
        , c , d ")` results in `["a", "b", "c , d"]`.

        Arguments
        - maxItems: the maximum number of items returned

        Returns
        - a splitter with the desired configuration

        Since
        - 9.0
        """
        ...


    def trimResults(self) -> "Splitter":
        """
        Returns a splitter that behaves equivalently to `this` splitter, but automatically
        removes leading and trailing CharMatcher.whitespace whitespace from each returned
        substring; equivalent to `trimResults(CharMatcher.whitespace())`. For example, `Splitter.on(',').trimResults().split(" a, b ,c ")` returns an iterable containing `["a",
        "b", "c"]`.

        Returns
        - a splitter with the desired configuration
        """
        ...


    def trimResults(self, trimmer: "CharMatcher") -> "Splitter":
        ...


    def split(self, sequence: "CharSequence") -> Iterable[str]:
        """
        Splits `sequence` into string components and makes them available through an Iterator, which may be lazily evaluated. If you want an eagerly computed List, use
        .splitToList(CharSequence). Java 8+ users may prefer .splitToStream instead.

        Arguments
        - sequence: the sequence of characters to split

        Returns
        - an iteration over the segments split from the parameter
        """
        ...


    def splitToList(self, sequence: "CharSequence") -> list[str]:
        """
        Splits `sequence` into string components and returns them as an immutable list. If you
        want an Iterable which may be lazily evaluated, use .split(CharSequence).

        Arguments
        - sequence: the sequence of characters to split

        Returns
        - an immutable list of the segments split from the parameter

        Since
        - 15.0
        """
        ...


    def splitToStream(self, sequence: "CharSequence") -> "Stream"[str]:
        """
        Splits `sequence` into string components and makes them available through an Stream, which may be lazily evaluated. If you want an eagerly computed List, use
        .splitToList(CharSequence).

        Arguments
        - sequence: the sequence of characters to split

        Returns
        - a stream over the segments split from the parameter

        Since
        - 28.2
        """
        ...


    def withKeyValueSeparator(self, separator: str) -> "MapSplitter":
        """
        Returns a `MapSplitter` which splits entries based on this splitter, and splits entries
        into keys and values using the specified separator.

        Since
        - 10.0
        """
        ...


    def withKeyValueSeparator(self, separator: str) -> "MapSplitter":
        """
        Returns a `MapSplitter` which splits entries based on this splitter, and splits entries
        into keys and values using the specified separator.

        Since
        - 14.0
        """
        ...


    def withKeyValueSeparator(self, keyValueSplitter: "Splitter") -> "MapSplitter":
        """
        Returns a `MapSplitter` which splits entries based on this splitter, and splits entries
        into keys and values using the specified key-value splitter.
        
        Note: Any configuration option configured on this splitter, such as .trimResults,
        does not change the behavior of the `keyValueSplitter`.
        
        Example:
        
        ````String toSplit = " x -> y, z-> a ";
        Splitter outerSplitter = Splitter.on(',').trimResults();
        MapSplitter mapSplitter = outerSplitter.withKeyValueSeparator(Splitter.on("->"));
        Map<String, String> result = mapSplitter.split(toSplit);
        assertThat(result).isEqualTo(ImmutableMap.of("x ", " y", "z", " a"));````

        Since
        - 10.0
        """
        ...


    class MapSplitter:
        """
        An object that splits strings into maps as `Splitter` splits iterables and lists. Like
        `Splitter`, it is thread-safe and immutable. The common way to build instances is by
        providing an additional Splitter.withKeyValueSeparator key-value separator to
        Splitter.

        Since
        - 10.0
        """

        def split(self, sequence: "CharSequence") -> dict[str, str]:
            """
            Splits `sequence` into substrings, splits each substring into an entry, and returns an
            unmodifiable map with each of the entries. For example, `Splitter.on(';').trimResults().withKeyValueSeparator("=>").split("a=>b ; c=>b")` will return
            a mapping from `"a"` to `"b"` and `"c"` to `"b"`.
            
            The returned map preserves the order of the entries from `sequence`.

            Raises
            - IllegalArgumentException: if the specified sequence does not split into valid map
                entries, or if there are duplicate keys
            """
            ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.OminousBottleMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class OminousBottleMeta(ItemMeta):
    """
    Represents a map that can be scalable.
    """

    def hasAmplifier(self) -> bool:
        """
        Checks for the presence of an amplifier.

        Returns
        - True if a customer amplifier is applied
        """
        ...


    def getAmplifier(self) -> int:
        """
        Gets the amplifier amount for an Ominous Bottle's bad omen effect.
        
        Plugins should check that hasAmplifier() returns True before calling this
        method.

        Returns
        - amplifier
        """
        ...


    def setAmplifier(self, amplifier: int) -> None:
        """
        Sets the amplifier amount for an Ominous Bottle's bad omen effect.

        Arguments
        - amplifier: between 0 and 4
        """
        ...


    def clone(self) -> "OminousBottleMeta":
        ...



"""
Python module generated from Java source file com.google.common.collect.NaturalOrdering

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations.concurrent import LazyInit
from java.io import Serializable
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class NaturalOrdering(Ordering, Serializable):
    """
    An ordering that uses the natural order of the values.
    """

    def compare(self, left: "Comparable"[Any], right: "Comparable"[Any]) -> int:
        ...


    def nullsFirst(self) -> "Ordering"["S"]:
        ...


    def nullsLast(self) -> "Ordering"["S"]:
        ...


    def reverse(self) -> "Ordering"["S"]:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.error.MarkedYAMLException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import *
from typing import Any, Callable, Iterable, Tuple


class MarkedYAMLException(YAMLException):

    def getMessage(self) -> str:
        ...


    def toString(self) -> str:
        ...


    def getContext(self) -> str:
        ...


    def getContextMark(self) -> "Mark":
        ...


    def getProblem(self) -> str:
        ...


    def getProblemMark(self) -> "Mark":
        ...



"""
Python module generated from Java source file net.md_5.bungee.chat.TextComponentSerializer

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import JsonDeserializationContext
from com.google.gson import JsonDeserializer
from com.google.gson import JsonElement
from com.google.gson import JsonObject
from com.google.gson import JsonParseException
from com.google.gson import JsonSerializationContext
from com.google.gson import JsonSerializer
from java.lang.reflect import Type
from net.md_5.bungee.api.chat import TextComponent
from net.md_5.bungee.chat import *
from typing import Any, Callable, Iterable, Tuple


class TextComponentSerializer(BaseComponentSerializer, JsonSerializer, JsonDeserializer):

    def deserialize(self, json: "JsonElement", typeOfT: "Type", context: "JsonDeserializationContext") -> "TextComponent":
        ...


    def serialize(self, src: "TextComponent", typeOfSrc: "Type", context: "JsonSerializationContext") -> "JsonElement":
        ...



"""
Python module generated from Java source file com.google.common.collect.SortedSetMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Comparator
from java.util import SortedMap
from java.util import SortedSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SortedSetMultimap(SetMultimap):
    """
    A `SetMultimap` whose set of values for a given key are kept sorted; that is, they comprise
    a SortedSet. It cannot hold duplicate key-value pairs; adding a key-value pair that's
    already in the multimap has no effect. This interface does not specify the ordering of the
    multimap's keys. See the Multimap documentation for information common to all multimaps.
    
    The .get, .removeAll, and .replaceValues methods each return a SortedSet of values, while Multimap.entries() returns a Set of map entries.
    Though the method signature doesn't say so explicitly, the map returned by .asMap has
    `SortedSet` values.
    
    **Warning:** As in all SetMultimaps, do not modify either a key *or a value*
    of a `SortedSetMultimap` in a way that affects its Object.equals behavior (or its
    position in the order of the values). Undefined behavior and bugs will result.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multimap">`Multimap`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    def get(self, key: "K") -> "SortedSet"["V"]:
        """
        Returns a collection view of all values associated with a key. If no mappings in the multimap
        have the provided key, an empty collection is returned.
        
        Changes to the returned collection will update the underlying multimap, and vice versa.
        
        Because a `SortedSetMultimap` has unique sorted values for a given key, this method
        returns a SortedSet, instead of the java.util.Collection specified in the
        Multimap interface.
        """
        ...


    def removeAll(self, key: "Object") -> "SortedSet"["V"]:
        """
        Removes all values associated with a given key.
        
        Because a `SortedSetMultimap` has unique sorted values for a given key, this method
        returns a SortedSet, instead of the java.util.Collection specified in the
        Multimap interface.
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> "SortedSet"["V"]:
        """
        Stores a collection of values with the same key, replacing any existing values for that key.
        
        Because a `SortedSetMultimap` has unique sorted values for a given key, this method
        returns a SortedSet, instead of the java.util.Collection specified in the
        Multimap interface.
        
        Any duplicates in `values` will be stored in the multimap once.
        """
        ...


    def asMap(self) -> dict["K", Iterable["V"]]:
        """
        Returns a map view that associates each key with the corresponding values in the multimap.
        Changes to the returned map, such as element removal, will update the underlying multimap. The
        map does not support `setValue()` on its entries, `put`, or `putAll`.
        
        When passed a key that is present in the map, `asMap().get(Object)` has the same
        behavior as .get, returning a live collection. When passed a key that is not present,
        however, `asMap().get(Object)` returns `null` instead of an empty collection.
        
        **Note:** The returned map's values are guaranteed to be of type SortedSet. To
        obtain this map with the more specific generic type `Map<K, SortedSet<V>>`, call Multimaps.asMap(SortedSetMultimap) instead. **However**, the returned map *itself* is
        not necessarily a SortedMap: A `SortedSetMultimap` must expose the *values*
        for a given key in sorted order, but it need not expose the *keys* in sorted order.
        Individual `SortedSetMultimap` implementations, like those built with MultimapBuilder.treeKeys(), may make additional guarantees.
        """
        ...


    def valueComparator(self) -> "Comparator"["V"]:
        """
        Returns the comparator that orders the multimap values, with `null` indicating that
        natural ordering is used.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.CartesianList

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.common.math import IntMath
from java.util import AbstractList
from java.util import ListIterator
from java.util import RandomAccess
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class CartesianList(AbstractList, RandomAccess):
    """
    Implementation of Lists.cartesianProduct(List).

    Author(s)
    - Louis Wasserman
    """

    def indexOf(self, o: "Object") -> int:
        ...


    def lastIndexOf(self, o: "Object") -> int:
        ...


    def get(self, index: int) -> "ImmutableList"["E"]:
        ...


    def size(self) -> int:
        ...


    def contains(self, object: "Object") -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.entity.Firework

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.inventory.meta import FireworkMeta
from typing import Any, Callable, Iterable, Tuple


class Firework(Projectile):

    def getFireworkMeta(self) -> "FireworkMeta":
        """
        Get a copy of the fireworks meta

        Returns
        - A copy of the current Firework meta
        """
        ...


    def setFireworkMeta(self, meta: "FireworkMeta") -> None:
        """
        Apply the provided meta to the fireworks

        Arguments
        - meta: The FireworkMeta to apply
        """
        ...


    def setAttachedTo(self, entity: "LivingEntity") -> bool:
        """
        Set the LivingEntity to which this firework is attached.
        
        When attached to an entity, the firework effect will act as normal but
        remain positioned on the entity. If the entity `LivingEntity.isGliding()
        is gliding`, then the entity will receive a boost in the direction that
        they are looking.

        Arguments
        - entity: the entity to which the firework should be attached, or
        null to remove the attached entity

        Returns
        - True if the entity could be attached, False if the firework was
        already detonated
        """
        ...


    def getAttachedTo(self) -> "LivingEntity":
        """
        Get the LivingEntity to which this firework is attached.
        
        When attached to an entity, the firework effect will act as normal but
        remain positioned on the entity. If the entity `LivingEntity.isGliding()
        is gliding`, then the entity will receive a boost in the direction that
        they are looking.

        Returns
        - the attached entity, or null if none
        """
        ...


    def setLife(self, ticks: int) -> bool:
        """
        Set the ticks that this firework has been alive. If this value exceeds
        .getMaxLife(), the firework will detonate.

        Arguments
        - ticks: the ticks to set. Must be greater than or equal to 0

        Returns
        - True if the life was set, False if this firework has already detonated
        """
        ...


    def getLife(self) -> int:
        """
        Get the ticks that this firework has been alive. When this value reaches
        .getMaxLife(), the firework will detonate.

        Returns
        - the life ticks
        """
        ...


    def setMaxLife(self, ticks: int) -> bool:
        """
        Set the time in ticks this firework will exist until it is detonated.

        Arguments
        - ticks: the ticks to set. Must be greater than 0

        Returns
        - True if the time was set, False if this firework has already detonated
        """
        ...


    def getMaxLife(self) -> int:
        """
        Get the time in ticks this firework will exist until it is detonated.

        Returns
        - the maximum life in ticks
        """
        ...


    def detonate(self) -> None:
        """
        Cause this firework to explode at earliest opportunity, as if it has no
        remaining fuse.
        """
        ...


    def isDetonated(self) -> bool:
        """
        Check whether or not this firework has detonated.

        Returns
        - True if detonated, False if still in the world
        """
        ...


    def isShotAtAngle(self) -> bool:
        """
        Gets if the firework was shot at an angle (i.e. from a crossbow).
        
        A firework which was not shot at an angle will fly straight upwards.

        Returns
        - shot at angle status
        """
        ...


    def setShotAtAngle(self, shotAtAngle: bool) -> None:
        """
        Sets if the firework was shot at an angle (i.e. from a crossbow).
        
        A firework which was not shot at an angle will fly straight upwards.

        Arguments
        - shotAtAngle: the new shotAtAngle
        """
        ...
